@@ -1,4 +1,4 @@
-## Copyright (C) 2013 Philip Nienhuis
+## Copyright (C) 2013-2015 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -28,16 +28,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis at users.sf.net>
 ## Created: 2013-09-08
-## Updates
-## 2013-09-30 Use regexp for start & end positions as index catches false positives
-## 2013-10-01 Input validation
-##     ''     Further simplified using regexp
-##     ''     Option to return just node contents
-## 2013-10-02 Speed up using regexp options
-## 2013-10-20 Fix typos in input validation error messages
-##     ''     Better input validation
-## 2013-11-04 More robust <single node/> detection
-## 2014-04-26 Fix error messages (no more traceback)
 
 function [ node, spos, epos ] = getxmlnode (xml, tag, is=1, contnt=0)
 
