@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -28,9 +28,9 @@
 ## A subsequent call to xlsclose is needed to write the updated spreadsheet
 ## to disk (and -if needed- close the Excel or Java invocation).
 ##
-## @var{arr} can be any 1D or 2D array containing numerical or character
-## data (cellstr) except complex. Mixed numeric/text arrays can only be
-## cell arrays.
+## @var{arr} can be any 1D or 2D array containing numerical, logical and/or
+## character data (cellstr) except complex.  Mixed type arrays can
+## only be cell arrays.
 ##
 ## @var{xls} must be a valid pointer struct created earlier by xlsopen.
 ##
@@ -42,13 +42,16 @@
 ## names or numbers, or whether @var{wsh} refers to an existing sheet with
 ## a type other than worksheet (e.g., chart).
 ## When new worksheets are to be added to the Excel file, they are
-## inserted to the right of all existing worksheets. The pointer to the
+## inserted to the right of all existing worksheets.  The pointer to the
 ## "active" sheet (shown when Excel opens the file) remains untouched.
 ##
 ## If @var{range} is omitted or just the top left cell of the range is
 ## specified, the actual range to be used is determined by the size of
-## @var{arr}. If nothing is specified for @var{range} the top left cell
-## is assumed to be 'A1'.
+## @var{arr}.  If nothing is specified for @var{range} the top left cell
+## is assumed to be 'A1'.  If defined in the spreadsheet file, a "Named
+## range" can also be specified.  In that case @var{wsh} will be ignored
+## and the worksheet associated with the specified Named range will be
+## used.
 ##
 ## Data are added to the worksheet, ignoring other data already present;
 ## existing data in the range to be used will be overwritten.
@@ -67,13 +70,13 @@
 ## default).
 ##
 ## Beware that -if invoked- Excel invocations may be left running silently
-## in case of COM errors. Invoke xlsclose with proper pointer struct to
+## in case of COM errors.  Invoke xlsclose with proper pointer struct to
 ## close them.
 ## When using Java, note that large data array sizes elements may exhaust
 ## the Java shared memory space for the default java memory settings.
 ## For larger arrays, appropriate memory settings are needed in the file
 ## java.opts; then the maximum array size for the Java-based spreadsheet
-## options may be in the order of 10^6 elements. In caso of UNO this
+## options may be in the order of 10^6 elements.  In caso of UNO this
 ## limit is not applicable and spreadsheets may be much larger.
 ##
 ## Examples:
@@ -88,35 +91,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis at users sf net>
 ## Created: 2009-12-01
-## Updates: 
-## 2010-01-03 (OOXML support / POI)
-## 2010-03-14 Updated help text section on Java memory usage
-## 2010-07-27 Added formula writing support (based on patch by Benjamin Lindner)
-## 2010-08-01 Added check on input array size vs. spreadsheet capacity
-##     ''     Changed argument topleft into range (now compatible with ML); the
-##     ''     old argument version (just topleft cell) is still recognized, though
-## 2010-08014 Added char array conversion to 1x1 cell for character input arrays
-## 2010-08-16 Added check on presence of output argument. Made wsh = 1 default
-## 2010-08-17 Corrected texinfo ("topleft" => "range")
-## 2010-08-25 Improved help text (section on java memory usage)
-## 2010-11-12 Moved ptr struct check into main func. More input validity checks
-## 2010-11-13 Added check for 2-D input array
-## 2010-12-01 Better check on file pointer struct (ischar (xls.xtype))
-## 2011-03-29 OpenXLS support added. Works but saving to file (xlsclose) doesn't work yet 
-##      ''    Bug fixes (stray variable c_arr, and wrong test for valid xls struct)
-## 2011-05-18 Experimental UNO support
-## 2011-09-08 Bug fix in range arg check; code cleanup
-## 2011-11-18 Fixed another bug in test for range parameter being character string
-## 2012-01-26 Fixed "seealso" help string
-## 2012-02-20 Fixed range parameter to be default empty string rather than empty numeral
-## 2012-02-27 More range param fixes
-## 2012-03-07 Updated texinfo help text
-## 2012-05-22 Cast all numeric data in input array to double
-## 2012-10-12 Moved all interface-specific subfubcs into ./private
-## 2012-10-24 Style fixes
-## 2012-12-18 Improved error/warning messages
-## 2012-12-29 Style fixes
-## 2014-01-29 Allow OCT write support for OOXML & ODS & gnumeric
 
 function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
 
@@ -133,10 +107,10 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
     obj = {obj};
     printf ("(oct2xls: input character array converted to 1x1 cell)\n");
   elseif (! iscell (obj))
-    error ("oct2xls: input array neither cell nor numeric array");
+    error ("oct2xls: input array neither cell nor numeric array\n");
   endif
   if (ndims (obj) > 2)
-    error ("oct2xls: only 2-dimensional arrays can be written to spreadsheet"); 
+    error ("oct2xls: only 2-dimensional arrays can be written to spreadsheet\n"); 
   endif
   ## Cast all numerical values to double as spreadsheets only have double/boolean/text type
   idx = cellfun (@isnumeric, obj, "UniformOutput", true);
@@ -149,19 +123,23 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
   test1 = test1 || isempty (xls.app);
   test1 = test1 || ! ischar (xls.xtype);
   if (test1)
-    error ("oct2xls: invalid xls file pointer struct");
+    error ("oct2xls: invalid xls file pointer struct\n");
   endif
 
   ## Check worksheet ptr
   if (! (ischar (wsh) || isnumeric (wsh)))
-    error ("Integer (index) or text (wsh name) expected for arg # 3");
+    error ("Integer (index) or text (wsh name) expected for arg # 3\n");
   endif
 
   ## Check range
   if (! isempty (crange) && ! ischar (crange))
-    error ("oct2xls: character string expected for arg # 4 (range)");
+    error ("oct2xls: character string expected for arg # 4 (range)\n");
   elseif (isempty (crange))
     crange = "";
+  elseif (! isempty (crange))
+    ## Check for range name and convert it to range & optionally sheet
+    ## 1. Check if it matches a range
+    [crange, wsh, xls] = chknmrange (xls, crange, wsh);
   endif
 
   ## Various options 
@@ -175,7 +153,7 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
     ## other options to be implemented here
 
   else
-    error ("oct2xls: structure expected for arg # 5");
+    error ("oct2xls: structure expected for arg # 5\n");
   endif
   
   if (nargout < 1)
@@ -204,7 +182,7 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
 ##elseif (strcmpi (xls.xtype, "<whatever>"))
     ##<Other Excel interfaces>
   else
-    error (sprintf ("oct2xls: unknown Excel .xls interface - %s.", xls.xtype));
+    error (sprintf ("oct2xls: unknown Excel .xls interface - %s.\n", xls.xtype));
   endif
 
 endfunction
