@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -19,22 +19,16 @@
 ## @deftypefnx {Function File} [@var{ods}] = odsclose (@var{ods}, "FORCE")
 ## Close the OpenOffice_org Calc / Gnumeric spreadsheet pointed to in struct
 ## @var{ods}, if needed write the file to disk.
+##
 ## odsclose will determine if the file must be written to disk based on
 ## information contained in @var{ods}.
 ## An empty pointer struct will be returned if no errors occurred. 
 ## Optional argument @var{filename} can be used to write changed spreadsheet
 ## files to an other file than opened by odsopen().
 ## Optional string argument "FORCE" can be specified to force resetting the
-## file pointer struct. However, in case of UNO, a hidden OOo invocation
+## file pointer struct.  However, in case of UNO, a hidden OOo invocation
 ## may linger on in memory then, preventing proper closing of Octave.
 ##
-## For writing .ods files you need the Java package >= 1.2.6 plus odfdom.jar
-## + xercesImpl.jar and/or jopendocument-<version>.jar installed on your
-## computer + proper javaclasspath set, to make this function work at all.
-## For UNO support, Octave-Java package >= 1.2.9 is imperative;
-## furthermore the relevant classes had best be added to the javaclasspath by
-## utility function chk_spreadsheet_support().
-##
 ## @var{ods} must be a valid pointer struct made by odsopen() in the same
 ## octave session.
 ##
@@ -51,31 +45,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis at users.sf.net>
 ## Created: 2009-12-13
-## Updates:
-## 2010-01-08 (OTK ODS write support)
-## 2010-04-13 Improved help text a little bit
-## 2010-08-25 Swapped in texinfo help text
-## 2010-10-17 Fixed typo in error message about unknown interface
-## 2010-10-27 Improved file change tracking tru ods.changed
-## 2010-11-12 Keep ods file pointer when write errors occur.
-##     ''     Added optional filename arg to change filename to be written to
-## 2011-05-06 Experimental UNO support
-## 2011-05-07 In case of UNO, soffice now properly closed using xDesk
-## 2011-05-18 Saving newly created files using UNO supported now
-## 2011-09-08 FIXME - closing OOo kills all other OOo invocations (known Java-UNO issue)
-## 2012-01-26 Fixed "seealso" help string
-## 2012-06-08 tabs replaced by double space
-## 2012-09-03 Extended file renaming section to xlsclose equivalent
-## 2012-10-12 Move most interface-specific code to ./private subfuncs
-##     ''     Move "file ptr preserved" message to proper else clause
-## 2012-10-23 Style fixes
-## 2012-12-18 Improved error/warning messages
-## 2013-09-09 Native Octave interface ("OCT") for reading
-##      ''    Warning message for empty file ptr structs
-## 2013-10-02 Texinfo header adapted
-## 2013-12-01 Style fixes
-## 2014-04-13 Updated copyright strings
-## 2014-04-26 Fix error messages (no more traceback)
 
 function [ ods ] = odsclose (ods, varargs)
 
