@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -19,47 +19,36 @@
 ## @deftypefnx {Function File} [@var{numarr}, @var{txtarr}, @var{rawarr}, @var{limits}] = odsread (@var{filename}, @var{wsh}, @var{range})
 ## @deftypefnx {Function File} [@var{numarr}, @var{txtarr}, @var{rawarr}, @var{limits}] = odsread (@var{filename}, @var{wsh}, @var{range}, @var{reqintf})
 ##
-## Read data contained from cell range @var{range} in worksheet @var{wsh}
-## in OpenOffice_org Calc spreadsheet file @var{filename}. Reading
+## Read data contained in cell range @var{range} in worksheet @var{wsh}
+## in OpenOffice_org Calc spreadsheet file @var{filename}.  Reading
 ## Gnumeric xml files is also supported.
 ##
-## A native Octave interface (OCT) is available, but presently still
-## experimental. For ODS only the supported Java-based interfaces offer
-## more flexibility and better speed. For those you need a Java JRE or JDK
-## and one or both of jopendocument-<version>.jar or preferrably: (odfdom.jar
-## (versions 0.7.5 or 0.8.6-0.8.8) & xercesImpl.jar v. 2.9.1) in your
-## javaclasspath. There is also experimental support invoking
-## OpenOffice.org/LibreOffice or clones through a Java/UNO bridge.
-## The OCT interface also offers .gnumeric read support.
-##
-## Return argument @var{numarr} contains the numeric data, optional
-## return arguments @var{txtarr} and @var{rawarr} contain text strings
-## and the raw spreadsheet cell data, respectively, and @var{limits} is
-## a struct containing the data origins of the various returned arrays.
-##
-## If @var{filename} does not contain any directory, the file is
-## assumed to be in the current directory. @var{filename} should include
-## the filename extension (.ods).
+## @var{filename} should include the filename extension (e.g., .ods).
 ##
 ## @var{wsh} is either numerical or text, in the latter case it is 
 ## case-sensitive and it should conform to OpenOffice.org Calc or
 ## Gnumeric sheet name requirements.
 ## Note that in case of a numerical @var{wsh} this number refers to the
 ## position in the worksheet stack, counted from the left in a Calc
-## window. The default is numerical 1, i.e. the leftmost worksheet
+## window.  The default is numerical 1, i.e. the leftmost worksheet
 ## in the Calc file.
 ##
 ## @var{range} is expected to be a regular spreadsheet range format,
 ## or "" (empty string, indicating all data in a worksheet).
 ## If no range is specified the occupied cell range will have to be
 ## determined behind the scenes first; this can take some time.
+## Instead of a spreadsheet range a Named range defined in the
+## spreadsheet file can be used as well. In that case the Named range
+## should be specified as 3rd argument and the value of 2nd argument
+## @var{wsh} doesn't matter as the worksheet associated with the
+## specified Named range will be used.
 ##
 ## If only the first argument is specified, odsread will try to read
 ## all contents from the first = leftmost (or the only) worksheet (as
 ## if a range of @'' (empty string) was specified).
 ## 
 ## If only two arguments are specified, odsread assumes the second
-## argument to be @var{wsh} and to refer to a worksheet. In that case
+## argument to be @var{wsh} and to refer to a worksheet.  In that case
 ## odsread tries to read all data contained in that worksheet.
 ##
 ## The optional last argument @var{reqintf} can be used to override 
@@ -69,14 +58,19 @@
 ## selects one of these, preferrably in the order above, based on
 ## presence of support software and the file at hand.
 ##
+## Return argument @var{numarr} contains the numeric data, optional
+## return arguments @var{txtarr} and @var{rawarr} contain text strings
+## and the raw spreadsheet cell data, respectively, and @var{limits} is
+## a struct containing the data origins of the various returned arrays.
+##
 ## Erroneous data and empty cells are set to NaN in @var{numarr} and
-## turn up empty in @var{txtarr} and @var{rawarr}. Date/time values
+## turn up empty in @var{txtarr} and @var{rawarr}.  Date/time values
 ## in date/time formatted cells are returned as numerical values in
-## @var{obj} with base 1-1-000. Note that OpenOfice.org and MS-Excel
-## have different date base values (1/1/0000 & 1/1/1900, resp.) and
-## internal representation so MS-Excel spreadsheets rewritten into
+## @var{obj} with base 1-1-0000.  Note that OpenOfice.org and MS-Excel
+## have different date base values (epoch; 1/1/0000 & 1/1/1900, resp.)
+## and internal representation so MS-Excel spreadsheets rewritten into
 ## .ods format by OpenOffice.org Calc may have different date base
-## values.
+## values than expected.
 ## As there's no gnumeric formula evaluator and gnumeric doesn't store
 ## cached formula results, formulas are returned as text strings when
 ## reading from Gnumeric files.
@@ -89,12 +83,23 @@
 ## to the leftmost or upper spreadsheet cell will be treated as if the
 ## "corresponding" cells are empty.
 ##
-## odsread is just a wrapper for a collection of scripts that find out
-## the interface to be used and do the actual reading. For each call
+## A native Octave interface (OCT) is available, but presently still
+## experimental; it offers .gnumeric read support as well.
+## For ODS only the supported Java-based interfaces offer more flexibility
+## and better speed.  For those you need a Java JRE or JDK and one or both
+## of jopendocument-<version>.jar or preferrably: (odfdom.jar (versions
+## 0.7.5 or 0.8.6-0.8.8) & xercesImpl.jar v. 2.9.1) in your javaclasspath.
+## There is also experimental support invoking OpenOffice.org/LibreOffice
+## or clones through a Java/UNO bridge.  For Octave older than 3.8.0 the
+## octave-forge Java package >= 1.2.9 is required then; newer Octave versions
+## should have Java support built-in.
+##
+## odsread,m is just a wrapper for a collection of scripts that find out
+## the interface to be used and do the actual reading.  For each call
 ## to odsread the interface must be started and the spreadsheet file read into
-## memory. When reading multiple ranges (in optionally multiple worksheets)
+## memory.  When reading multiple ranges (in optionally multiple worksheets)
 ## a significant speed boost can be obtained by invoking those scripts
-## directly (odsopen / ods2oct [/ parsecell] / ... / odsclose). This also 
+## directly (odsopen / ods2oct [/ parsecell] / ... / odsclose).  This also 
 ## offers more flexibility (e.g. formula results or the formulas
 ## themselves; stripping output arrays from empty enveloping rows/columns).
 ##
@@ -119,30 +124,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis at users.sf.net>
 ## Created: 2009-12-12
-## Updates: 
-## 2010-01-05 (....)
-## 2010-03-04 Slight adaptations in texinfo
-## 2010-05-31 Updated help text (delays i.c.o. empty range due to getusedrange call)
-## 2010-11-10 Updated help text (filename extension req'd)
-## 2010-11-13 Added some input validity checks
-## 2011-09-08 Catch empty ods structs after failed odsopen attempts
-## 2011-09-18 Return empty output arg in case of empty rawarr
-## 2012-01-26 Fixed "seealso" help string
-## 2012-03-07 Updated texinfo help text
-## 2012-06-08 Tabs replaced by double space
-## 2012-10-24 Style fixes
-## 2013-09-24 Drop requirement of having at least one output arg
-## 2013-09-27 Check for proper filename in input
-## 2013-09-27 Better filename suffix check
-##     ''     Updated header
-## 2013-10-02 Some adaptations for gnumeric support
-##     ''     Texinfo header adapted
-## 2013-11-04 Better error message about unsupported file types
-##     ''     Add .sxc to supported file types
-## 2013-12-01 Updated texinfo header
-## 2014-04-13 Updated copyright strings and texinfo header
-## 2014-04-15 More updates to texinfo header
-## 2014-04-26 Fix error messages (no more traceback)
 
 function [ numarr, txtarr, rawarr, lim ] = odsread (filename, wsh=1, datrange=[], reqintf=[])
 
@@ -152,7 +133,7 @@ function [ numarr, txtarr, rawarr, lim ] = odsread (filename, wsh=1, datrange=[]
   if (nargin < 1 || ! (strcmpi (".ods", filename(end-3:end)) || ...
                        strcmpi (".sxc", filename(end-3:end)) || ...
                        strcmpi (".gnumeric", filename(end-8:end))))
-    usage ("odsread: filename (incl. suffix) of a supported file type is required");
+    error ("odsread: filename (incl. suffix) of a supported file type is required\n");
   endif
 
   ods = odsopen (filename, 0, reqintf);
