@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -20,32 +20,36 @@
 ## @deftypefnx {Function File} @var{rstatus} = odswrite (@var{filename}, @var{arr}, @var{wsh}, @var{range}, @var{reqintf})
 ## Add data in 1D/2D array @var{arr} into sheet @var{wsh} in
 ## OpenOffice_org Calc spreadsheet file @var{filename} in cell range
-## @var{range}. Gnumeric files can also be written.
+## @var{range}.  Gnumeric files can also be written.
 ##
 ## @var{rstatus} returns 1 if write succeeded, 0 otherwise.
 ##
 ## @var{filename} must be a valid .ods OpenOffice.org file name (including
-## file name extension). If @var{filename} does not contain any directory
+## file name extension).  If @var{filename} does not contain any directory
 ## path, the file is saved in the current directory.
 ##
-## @var{arr} can be any 1D or 2D array containing numerical or character
-## data (cellstr) except complex. Mixed numeric/text arrays can only be
-## cell arrays.
+## @var{arr} can be any 1D or 2D array containing numerical, logical and/or
+## character data (cellstr) except complex.  Mixed numeric/logical/text
+## arrays can only be cell arrays.
 ##
-## @var{wsh} can be a number or string. In case of a not yet existing
+## @var{wsh} can be a number or string.  In case of a not yet existing
 ## OpenOffice.org spreadsheet, the first sheet will be used & named
 ## according to @var{wsh} - no extra empty sheets are created.
 ## In case of existing files, some checks are made for existing sheet
 ## names or numbers, or whether @var{wsh} refers to an existing sheet with
 ## a type other than sheet (e.g., chart).
 ## When new sheets are to be added to the spreadsheet file, they are
-## inserted to the right of all existing sheets. The pointer to the
+## inserted to the right of all existing sheets.  The pointer to the
 ## "active" sheet (shown when OpenOffice.org Calc opens the file) remains
 ## untouched.
 ##
 ## @var{range} is expected to be a regular spreadsheet range.
 ## Data is added to the sheet; existing data in the requested
-## range will be overwritten.
+## range will be overwritten.  Instead of a spreadsheet range a Named
+## range defined in the spreadsheet file can be used as well. In that
+## case the Named range should be specified as 4th argument and the value
+## of 3rd argument @var{wsh} doesn't matter as the worksheet associated
+## with the specified Named range will be used.
 ## Array @var{arr} will be clipped at the right and/or bottom if its size
 ## is bigger than can be accommodated in @var{range}.
 ## If @var{arr} is smaller than the @var{range} allows, it is placed
@@ -69,7 +73,7 @@
 ## native Octave) plus code to mimic the other brand's xlswrite syntax
 ## (and quirks).
 ## For each call to odswrite such an interface must be started and
-## possibly an ODS file loaded. When writing to multiple ranges and/or
+## possibly an ODS file loaded.  When writing to multiple ranges and/or
 ## worksheets in the same ODS file, a speed bonus can be obtained by
 ## invoking those scripts (odsopen / octods / .... / odsclose) directly.
 ##
@@ -88,29 +92,12 @@
 
 ## Author: Philip Nienhuis <pr.nienhuis at users.sf.net>
 ## Created: 2009-12-14
-## Updates:
-## 2010-01-14 Finalized write support tru ODS toolkit
-## 2010-01-15 Added texinfo help
-## 2010-08-25 Removed text about 31 char limit for sheet names (invalid)
-## 2010-11-13 Added note about required file extension in help text
-## 2010-11-13 Added some input arg checks
-## 2011-09-08 Minor filename error text adaptation
-## 2012-01-26 Fixed "seealso" help string
-## 2012-02-20 Fixed range parameter to be default empty string rather than empty numeral
-## 2010-03-07 Updated texinfo help text
-## 2012-06-08 Tabs replaced by double space
-## 2012-10-24 Style fixes
-## 2013-12-18 Copyright string updates, style fixes
-## 2014-01-01 Drop file extension check
-## 2014-04-13 Updated copyright strings & texinfo header
-## 2014-04-26 Fix error messages (no more traceback)
-## 2014-08-14 Return 0 in case non-empty file pointer after closing
 
 function [ rstatus ] = odswrite (filename, data, wsh=1, crange="", reqintf=[])
 
   ## Input validity checks
   if (nargin < 2)
-    usage ("Insufficient arguments - see 'help odswrite'");
+    error ("Insufficient arguments - see 'help odswrite'\n");
   endif
 
   ods = odsopen (filename, 1, reqintf);
