@@ -1,4 +1,4 @@
-## Copyright (C) 2010,2011,2012,2013 Philip Nienhuis
+## Copyright (C) 2010-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -17,10 +17,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2010-10-07
-## Updates:
-## 2012-10-12 Renamed & moved into ./private
-## 2012-10-24 Style fixes
-## 2012-12-01 Copyright string adapted
 
 function [ trow, brow, lcol, rcol ] = __COM_getusedrange__ (xls, ii)
 
