@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013 P.R. Nienhuis
+## Copyright (C) 2009-2015 P.R. Nienhuis
 ## parts Copyright (C) 2007 Michael Goffioul
 ##
 ## This program is free software; you can redistribute it and/or modify it under
@@ -36,22 +36,8 @@
 ## @end deftypefn
 
 ## Author: Philip Nienhuis <pr.nienhuis at hccnet.nl>
-## Based on mat2xls by Michael Goffioul (2007) <michael.goffioul@swing.be>
+## Based on mat2xls by Michael Goffioul (2007) <michael.goffioul@gmail.com>
 ## Created: 2009-09-23
-## Last updates:
-## 2009-12-11 <forgot what it was>
-## 2010-10-07 Implemented limits (only reliable for empty input ranges)
-## 2010-10-08 Resulting data array now cropped (also in case of specified range)
-## 2010-10-10 More code cleanup (shuffled xls tests & wsh ptr code before range checks)
-## 2010-10-20 Slight change to Excel range setup
-## 2010-10-24 Added check for "live" ActiveX server
-## 2010-11-12 Moved ptr struct check into main func
-## 2010-11-13 Catch empty sheets when no range was specified
-## 2012-01-26 Fixed "seealso" help string
-## 2012-06-06 Implemented "formulas_as_text option"
-## 2012-10-12 Renamed & moved into ./private
-## 2012-10-24 Style fixes
-## 2013-12-01 Copyright strings updates
 
 function [rawarr, xls, rstatus ] = __COM_spsh2oct__ (xls, wsh, crange, spsh_opts)
 
