@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -18,31 +18,6 @@
 ##
 ## Author: Philip Nienhuis <pr.nienhuis at users.sf.net>
 ## Created: 2009-12-13
-## First usable version: 2010-01-14
-## Updates:
-## 2010-03-17 Adapted to simplified calccelladdress argument list
-## 2010-04-24 Added ensureColumnCount & ensureRowCount
-##            Fixed a few bugs with top row & left column indexes
-##            Fixed a number of other stupid bugs
-##            Added check on NaN before assigning data value to sprdsh-cell
-## 2010-06-01 Checked logic. AFAICS all should work with upcoming jOpenDocument 1.2b4;
-##            in 1.2b3 adding a newsheet always leaves an incomplete upper row;
-##            supposedly (hopefully) that will be fixed in 1.2b4.
-##     ''     Added check for jOpenDocument version. Adding sheets only works for
-##            1.2b3+ (barring bug above)
-## 2010-06-02 Fixed first sheet remaining in new spreadsheets
-## 2010-08-01 Added option for crange to be only topleft cell address
-##     ''     Code cleanup
-## 2010-08-13 Fixed bug of ignoring text sheet name in case of new spreadsheet
-## 2010-08-15 Fixed bug with invalid first sheet in new spreadsheets
-## 2010-10-27 Improved file change tracking tru ods.changed
-## 2010-11-12 Improved file change tracking tru ods.changed
-## 2012-02-26 Write logicals as doubles (bug in jOpenDocument, would write as text)
-## 2012-10-12 Renamed & moved into ./private
-## 2012-10-24 Style fixes
-## 2013-12-01 Style fixes, copyright string updates
-## 2013-12-19 More style fixes
-##     ''     Work around jOpenDocument bug adding "A" to A1, "B" to B1 in new files
 
 function [ ods, rstatus ] = __JOD_oct2spsh__ (c_arr, ods, wsh, crange)
 
@@ -78,7 +53,7 @@ function [ ods, rstatus ] = __JOD_oct2spsh__ (c_arr, ods, wsh, crange)
     sh = ods.workbook.getSheet (wsh);
     if (isempty (sh))
       ## Still doesn't exist. Create sheet
-      if (ods.odfvsn == 3)
+      if (ods.odfvsn >= 3)
         if (ods.changed > 2)
           ## 1st "new" -unnamed- sheet has already been made when creating the spreadsheet
           sh = ods.workbook.getSheet (0);
@@ -161,8 +136,8 @@ function [ ods, rstatus ] = __JOD_oct2spsh__ (c_arr, ods, wsh, crange)
     for jj = 1 : ncols
       val = c_arr {ii, jj};
       if ((isnumeric (val) && ! isnan (val)) || ischar (val) || islogical (val))
-        ## FIXME: jOpenDocument doesn't really support writing booleans (doesn't set OffValAttr)
-        if (islogical (val))
+        ## jOpenDocument < 1.3 doesn't really support writing booleans (doesn't set OffValAttr)
+        if ((ods.odfvsn <= 3) && islogical (val))
           val = double (val);
         endif
         try
