@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -39,31 +39,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis at users.sf.net>
 ## Created: 2009-12-04
-## Updates:
-## 2009-12-11
-## 2010-01-12 Fixed skipping empty array values (now Excel-conformant => cell cleared)
-##            Added xls.changed = 1 statement to signal successful write
-## 2010-07-27 Added formula writing support (based on POI patch by Benjamin Lindner)
-##            Added check for valid file pointer struct
-## 2010-08-01 Improved try-catch for formulas to enter wrong formulas as text strings
-## 2010-08-01 Added range vs. array size vs. capacity checks
-##     ''     Code cleanup
-##     ''     Changed topleft arg into range arg (topleft version still recognized)
-## 2010-08-03 Moved range checks and cell type parsing to separate routines
-## 2010-08-11 Moved addcell() into try-catch as it is addCell which throws fatal errors
-## 2010-10-20 Improved logic for tracking file changes (xls.changed 2 or 3); dropped
-##     ''      internal variable 'changed'
-## 2010-10-27 File change tracking again refined
-## 2010-11-12 Moved ptr struct check into main func
-## 2012-01-26 Fixed "seealso" help string
-## 2012-02-27 Copyright strings updated
-## 2012-05-21 "Double" cast added when writing numeric values
-## 2012-05-21 "Double" cast moved into main func oct2xls
-## 2012-10-12 Renamed & moved into ./private
-## 2012-10-24 Style fixes
-## 2013-01-20 Adapted to ML-compatible Java calls
-## 2013-12-01 Style fixes, copyright string updates
-## 2013-12-27 Style fixes
 
 function [ xls, rstatus ] = __JXL_oct2spsh__ (obj, xls, wsh, crange, spsh_opts)
 
