@@ -1,4 +1,4 @@
-## Copyright (C) 2012,2013 Philip Nienhuis
+## Copyright (C) 2012-2015 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,15 +18,11 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2012-10-12
-## Updates:
-## 2012-10-24 Style fixes
-## 2013-12-01 Style fixes, copyright string updates
 
 function [ xls ] = __JXL_spsh_close__ (xls)
 
     if (xls.changed > 0 && xls.changed < 3)
       try
-##      if (xls.changed == 2); printf ("Saving file %s...\n", xls.filename); endif
         xls.workbook.write ();
         xls.workbook.close ();
         if (xls.changed == 3)
