@@ -1,4 +1,4 @@
-## Copyright (C) 2013,2014 Philip Nienhuis
+## Copyright (C) 2013-2015 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -23,19 +23,6 @@
 
 ## Author: Philip Nenhuis <prnienhuis at users.sf.net>
 ## Created: 2013-09-09
-## Updates:
-## 2013-09-23 Added in commented-out stanza for OOXML (.xlsx)
-## 2013-10-20 OOXML support
-## 2014-01-19 Write support for ODS
-## 2014-01-20 Catch zip errors; zip to proper (original) file name
-## 2014-01-22 Zip quietly; zip into current dir, not temp dir
-## 2014-01-24 Call confirm_recursive_subdir locally
-## 2014-01-28 Zip both .ods & xlsx, gzip .gnumeric
-##     ''     Reorganize code a bit
-## 2014-04-06 Fix filename arg in error msg
-##     ''     cd out of tmp dir before removing it
-## 2014-04-30 Gnumeric write support
-## 2014-08-25 Precautions to make sure we get back to original work dir
 
 function [xls] = __OCT_spsh_close__ (xls)
 
@@ -45,7 +32,7 @@ function [xls] = __OCT_spsh_close__ (xls)
   if (isempty (pth))
     filename = [ opwd filesep xls.filename ];
   else
-    filename = xls.filename;
+    filename = make_absolute_filename (xls.filename);
   endif
 
   ## .ods and.xlsx are both zipped
@@ -53,7 +40,7 @@ function [xls] = __OCT_spsh_close__ (xls)
     if (xls.changed && xls.changed < 3)
       ## Go to temp dir where ods file has been unzipped
       cd (xls.workbook);
-      sleep (0.05);
+            sleep (0.05);
       ## Zip tmp directory into .ods or .xlsx and copy it over original file
       try
         [stts, op] = system (sprintf ("zip -q -r %s *.* .", filename));
