@@ -1,4 +1,4 @@
-## Copyright (C) 2010,2011,2012,2013 Philip Nienhuis
+## Copyright (C) 2010-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -29,24 +29,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2010-01-07
-## Updates: 
-## 2010-01-14 (finally seems to work OK)
-## 2010-03-08 Some comment lines adapted
-## 2010-03-25 Try-catch added f. unpatched-for-booleans java-1.2.6 / 1.2.7 package
-## 2010-04-11 Changed all references to "cell" to "scell" to avoid reserved keyword
-##     ''     Small bugfix for cases with empty left columns (wrong cell reference)
-## 2010-04-13 Fixed bug with stray cell copies beyond added data rectangle
-## 2010-07-29 Added formula input support (based on xls patch by Benjamin Lindner)
-## 2010-08-01 Added try-catch around formula input
-##     ''     Changed range arg to also allow just topleft cell
-## 2010-08-03 Moved range checks and type array parsing to separate functions
-## 2010-08-13 Fixed empty Sheet1 in case of new spreadsheets, fix input text sheet name
-## 2010-10-27 Improved file change tracking tru ods.changed
-## 2010-11-12 Improved file change tracking tru ods.changed
-## 2012-10-12 Renamed & moved into ./private
-## 2012-10-24 Style fixes
-## 2013-01-20 Adapted to ML-compatible Java calls
-## 2013-12-01 Style fixes, copyright string updates
 
 function [ ods, rstatus ] = __OTK_oct2ods__ (c_arr, ods, wsh, crange, spsh_opts)
 
@@ -66,7 +48,7 @@ function [ ods, rstatus ] = __OTK_oct2ods__ (c_arr, ods, wsh, crange, spsh_opts)
   officestyles = ods.app.getOrCreateDocumentStyles();
 
   ## Create an instance of type NODESET for use in subsequent statements
-  NODESET = java_get ("javax.xml.xpath.XPathConstants", "NODESET");
+  NODESET = __java_get__ ("javax.xml.xpath.XPathConstants", "NODESET");
 
   ## Parse sheets ("tables") from ODS file
   sheets = xpath.evaluate ("//table:table", odfcont, NODESET);
@@ -114,7 +96,7 @@ function [ ods, rstatus ] = __OTK_oct2ods__ (c_arr, ods, wsh, crange, spsh_opts)
     c_arr = c_arr(1:nrows, 1:ncols);
   endif
   
-## Parse data array, setup typarr and throw out NaNs  to speed up writing;
+  ## Parse data array, setup typarr and throw out NaNs  to speed up writing;
   typearr = spsh_prstype (c_arr, nrows, ncols, ctype, spsh_opts, 0);
   if (! spsh_opts.formulas_as_text)
     ## Find formulas (designated by a string starting with "=" and ending in ")")
