@@ -1,4 +1,4 @@
-## Copyright (C) 2012,2013 Philip Nienhuis
+## Copyright (C) 2012-2015 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,9 +18,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2012-10-12
-## Updates:
-## 2012-10-23 Style fixes (none)
-## 2013-12-01 Copyright string updates
 
 function [ ods ] = __OTK_spsh_close__ (ods, force)
 
