@@ -1,4 +1,4 @@
-## Copyright (C) 2013 Philip Nienhuis
+## Copyright (C) 2013,2015 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,11 +18,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2012-10-12
-## Updates:
-## 2012-10-12 Moved into ./private
-## 2012-10-24 Style fixes
-## 2013-12-06 Updated copyright strings
-## 2012-12-29 Typo in comment line fixed
 
 function [sh_names] = __OXS_spsh_info__ (xls)
 
