@@ -1,4 +1,4 @@
-## Copyright (C) 2012,2013 Philip Nienhuis
+## Copyright (C) 2012-2015 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,16 +18,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2012-10-12
-## Updates:
-## 2012-10-23 Style fixes
-## 2013-01-20 Adapted to ML-compatible Java calls
-## 2013-12-06 Updated copyright strings
-## 2014-01-01 Fixed bug ignoring xls.nfilename
-##     ''     Simplified filename/nfilename code
-##     ''     First throw at output file type filters
-##     ''     Add ";" to suppress debug output
-## 2014-08-25 Add a little delay before terminating LO/OOo to allow
-##            zip finish low-level I/O
 
 function [ xls ] = __UNO_spsh_close__ (xls, force)
 
@@ -36,10 +26,10 @@ function [ xls ] = __UNO_spsh_close__ (xls, force)
     if (strcmp (xls.xtype, 'UNO'))
       ## For UNO, turn filename into URL
       nfilename = xls.nfilename;
-      if    (! isempty (strmatch ("file:///", nfilename))... 
-          || ! isempty (strmatch ("http://",  nfilename))...
-          || ! isempty (strmatch ("ftp://",   nfilename))...   
-          || ! isempty (strmatch ("www://",   nfilename)))
+      if    (! isempty (strfind (nfilename, "file:///"))... 
+          || ! isempty (strfind (nfilename, "http://" ))...
+          || ! isempty (strfind (nfilename, "ftp://"  ))...   
+          || ! isempty (strfind (nfilename, "www://"  )))
         ## Seems in proper shape for OOo (at first sight)
       else
         ## Transform into URL form
