@@ -1,4 +1,4 @@
-## Copyright (C) 2013 Philip Nienhuis
+## Copyright (C) 2013,2014 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,22 +18,24 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2013-03-01
-## 2013-11-05 Provide default values for jcp & tmp1
-## 2013-12-20 Copyright string updates
-##     ''     dbug info argument added (for chk_spreadsheet_support)
-##     ''     java_invoke -> javaMethod
-## 2014-01-08 Tiny style fix
 
 function [ tmp1, jcp ] = __chk_java_sprt__ (dbug=0)
 
   jcp = {};
   tmp1 = 0;
+  if (! octave_config_info.features.JAVA)
+    ## No Java support built in => any further checks are moot
+    return
+  endif
+
   try
-    jcp = javaclasspath ("-all");          # For java pkg >= 1.2.8
-    if (isempty (jcp)), jcp = javaclasspath; endif  # For java pkg <  1.2.8
+    jcp = javaclasspath ("-all");         # For java pkg >= 1.2.8
+    if (isempty (jcp))                    #   & Octave   >= 3.7.2
+      jcp = javaclasspath;                # For java pkg <  1.2.8 
+    endif
     ## If we get here, at least Java works. 
     if (dbug > 1)
-      printf ("Java seems to work OK.\n");
+      printf ("  Java seems to work OK.\n");
     endif
     ## Now check for proper version (>= 1.6)
     jver = ...
