@@ -1,4 +1,4 @@
-## Copyright (C) 2012,2013 Philip Nienhuis
+## Copyright (C) 2012-2015 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,15 +18,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2012-10-07
-## Updates:
-## 2012-10-23 Style fixes
-## 2012-12-18 Add option for range of names per required entry
-##     ''     Tests added
-## 2013-07-12 Trim implied padding of range of names per entry
-## 2012-07-18 Fix multiple equivalent jar entries bug (padding w. spaces
-##            overlooked)
-## 2013-12-06 Updated copyright strings; style fixes
-##     ''     Commented out tests
 
 function [ retval, missing ] = chk_jar_entries (jcp, entries, dbug=0)
 
