@@ -1,4 +1,4 @@
-## Copyright (C) 2010,2011,2012,2013 Philip Nienhuis
+## Copyright (C) 2010-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -54,25 +54,6 @@
 
 ## Author: Philip Nienhuis <pr.nienhuis@users.sf.net>
 ## Created: 2010-03-18 (First usable version) for ODS (java/OTK)
-## Updates:
-## 2010-03-20 Added Excel support (Java/POI)
-## 2010-05-23 Added in support for jOpenDocument ODS
-## 2010-05-31 Fixed bugs in getusedrange_jod.m
-## 2010-08-24 Added support for odfdom 0.8.6 (ODF Toolkit)
-## 2010-08-27 Added checks for input arguments
-##     ''     Indentation changed from tab to doublespace
-## 2010-10-07 Added COM support (at last!)
-## 2011-05-06 Experimental support for Java/UNO bridge
-## 2011-06-13 OpenXLS support added
-## 2011-09-08 Style & layout updates
-## 2012-01-26 Fixed "seealso" help string
-## 2012-06-08 Replaced tabs by double space
-##     ''     Added COM and OXS to message about supported interfaces
-## 2012-10-12 Moved all interface-specific subfuncs to . /private
-## 2012-10-23 Added UNO to error message
-##     ''     Style fixes
-## 2013-09-08 Added OCT (native ods & xlsx) interface
-## 2013-12-06 Updated copyright strings
 
 function [ trow, lrow, lcol, rcol ] = getusedrange (spptr, ii)
 
