@@ -1,4 +1,4 @@
-## Copyright (C) 2010,2011,2012,2013 Philip Nienhuis
+## Copyright (C) 2010-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -29,14 +29,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2010-08-02
-## Updates: 
-## 2010-08-25 Option for supplying file pointer rather than interface_type & filename
-##            (but this can be wasteful if the file ptr is copied)
-## 2011-03-29 Bug fix - unrecognized pointer struct & wrong type error msg
-## 2011-05-15 Experimental UNO support added (OpenOffice.org & clones)
-## 2011-09-18 Updated UNO data row capacity for LibreOffice 3.4+ (now 1,048,576 rows)
-## 2012-10-23 Style fixes
-## 2013-12-06 Updated copyright strings
 
 function [ topleft, nrows, ncols, trow, lcol ] = spsh_chkrange (crange, nr, nc, intf, filename=[])
 
@@ -56,7 +48,7 @@ function [ topleft, nrows, ncols, trow, lcol ] = spsh_chkrange (crange, nr, nc,
 	## Define max row & column capacity from interface type & file suffix
 	switch xtype
 		case { 'COM', 'POI' }
-			if (strmatch (tolower (filename(end-3:end)), '.xls'))
+			if (strcmpi (filename(end-3:end), '.xls'))
 				## BIFF5 & BIFF8
 				ROW_CAP = 65536;   COL_CAP = 256;
 			else
