@@ -1,4 +1,4 @@
-## Copyright (C) 2013,2014 Philip Nienhuis
+## Copyright (C) 2013-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -32,12 +32,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2013-04-21
-## Updates:
-## 2013-12-20 Updated texinfo header & copyright strings
-##     ''     Added OCT interface tests conditional of writing interfaces
-## 2013-12-31 Extended texinfo help text
-## 2014-04-25 Write support for OCT
-## 2014-01-05 Add tests for gnumeric
 
 function [] = test_spsh (numb = [])
 
@@ -47,29 +41,6 @@ function [] = test_spsh (numb = [])
   ## Get available interfaces
   avail_intf = uint16 (chk_spreadsheet_support ());
 
-  ## FIXME Sort out below code so that arbitrary bit patterns can be tested
-  ##       resembling the one returned by uint16 (chk_spreadsheet_support)
-  ##if (! isempty (numb))
-  ##  ## Check if numb makes sense
-  ##  if (ischar (numb))
-  ##    numb = lower (numb);
-  ##    ## First check if it is recognized in the list ofinterfaces
-  ##    if (ismember (numb, xls_intf) || ismember (numb, ods_intf))
-  ##      idx = strmatch (numb, [xls_intf ods_intf]);
-  ##      ## It is known; now check if it's actually supported at the moment
-  ##      if (bitget (avail_intf, idx))
-  ##        ## It is, set just that bit of avail_intf that's related to intf 'numb'
-  ##        avail_intf = bitset (uint16 (0), idx, 1);
-  ##      else
-  ##        ## It isn't, notify user
-  ##        error ("Requested interface \"%s\" presently not available\n", numb);
-  ##      endif
-  ##    else
-  ##      error ("Unknown interface - %s\n", numb);
-  ##    endif
-  ##  endif
-  ##endif
-
   ## First all Excel xls/xlsx interfaces
   intf2 = "";
   for ii = 1:numel (xls_intf)
