@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013 Philip Nienhuis <prnienhuis at users.sf.net>
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -18,29 +18,31 @@
 ## @deftypefnx {Function File} [@var{xls}] = xlsclose (@var{xls}, @var{filename})
 ## @deftypefnx {Function File} [@var{xls}] = xlsclose (@var{xls}, "FORCE")
 ## Close the Excel spreadsheet pointed to in struct @var{xls}, if needed
-## write the file to disk. Based on information contained in @var{xls},
+## write the file to disk.  Based on information contained in @var{xls},
 ## xlsclose will determine if the file should be written to disk.
 ##
 ## If no errors occured during writing, the xls file pointer struct will be
 ## reset and -if COM interface was used- ActiveX/Excel will be closed.
-## However if errors occurred, the file pinter will be untouched so you can
+## However if errors occurred, the file pointer will be untouched so you can
 ## clean up before a next try with xlsclose().
 ## Be warned that until xlsopen is called again with the same @var{xls} pointer
 ## struct, hidden Excel or Java applications with associated (possibly large)
 ## memory chunks are kept in memory, taking up resources.
 ## If (string) argument "FORCE" is supplied, the file pointer will be reset 
 ## regardless, whether the possibly modified file has been saved successfully
-## or not. Hidden Excel (COM) or OpenOffice.org (UNO) invocations may live on,
+## or not.  Hidden Excel (COM) or OpenOffice.org (UNO) invocations may live on,
 ## possibly even impeding proper shutdown of Octave.
 ##
 ## @var{filename} can be used to write changed spreadsheet files to
 ## an other file than opened with xlsopen(); unfortunately this doesn't work
 ## with JXL (JExcelAPI) interface.
 ##
-## You need MS-Excel (95 - 2010), and/or the Java package => 1.2.8 plus Apache
-## POI > 3.5 and/or JExcelAPI and/or OpenXLS and/or OpenOffice.org or clones
-## installed on your computer + proper javaclasspath set, to make this
-## function work at all.
+## For other file formats than OOXML, ODS or gnumeric, you need MS-Excel
+## (95 - 2010), and/or the Java package => 1.2.8 plus Apache POI > 3.5 and/or
+## JExcelAPI and/or OpenXLS and/or OpenOffice.org or clones installed on your
+## computer + proper javaclasspath set, to make this function work at all.
+## For Octave >= 3.8.0 the Java package isn't needed as Java support should
+## be built-in.
 ##
 ## @var{xls} must be a valid pointer struct made by xlsopen() in the same
 ## octave session.
@@ -56,37 +58,13 @@
 ##
 ## @end deftypefn
 
-## Author: Philip Nienhuis
+## Author: Philip Nienhuis <prnienhuis at users.sf.net>
 ## Created: 2009-11-29
-## Updates: 
-## 2010-01-03 (checked OOXML support)
-## 2010-08-25 See also: xlsopen (instead of xlsclose)
-## 2010-10-20 Improved tracking of file changes and need to write it to disk
-## 2010-10-27 Various changes to catch errors when writing to disk;
-##     "      Added input arg "keepxls" for use with xlswrite.m to save the
-##     "      untouched file ptr struct in case of errors rather than wipe it
-## 2010-11-12 Replaced 'keepxls' by new filename arg; catch write errors and
-##            always keep file pointer in case of write errors
-## 2011-03-26 Added OpenXLS support
-## 2011-05-18 Added experimental UNO support, incl. saving newly created files
-## 2011-09-08 Bug fix in check for filename input arg
-## 2012-01-26 Fixed "seealso" help string
-## 2012-09-03 (in UNO sections) replace canonicalize_file_name on non-Windows to
-##            make_absolute_filename (see bug #36677)
-##     ''     (in UNO section) web adresses need only two consecutive slashes
-## 2012-10-12 Move most interface-specific code to ./private subfuncs
-##     ''     Move "file ptr preserved" message to proper else clause
-## 2012-10-24 Style fixes
-## 2012-12-18 Improved error/warning messages
-## 2013-09-30 OCT interface added
-## 2013-10-01 Warn for empty struct input
-## 2013-12-29 Style fixes
-## 2014-01-01 Style fixes
 
 function [ xls ] = xlsclose (xls, varargs)
 
   if (isempty (xls))
-    warning ("xlsclose: file pointer struct was already closed");
+    warning ("xlsclose: file pointer struct was already closed\n");
     return
   endif
 
@@ -102,13 +80,13 @@ function [ xls ] = xlsclose (xls, varargs)
       elseif (! isempty (strfind (tolower (varargin{ii}), ".")))
         ## Apparently a file name. First some checks....
         if (xls.changed == 0 || xls.changed > 2)
-          warning ("xlsclose: file %s wasn't changed, new filename ignored.", xls.filename);
+          warning ("xlsclose: file %s wasn't changed, new filename ignored.\n", xls.filename);
         elseif (strcmp (xls.xtype, "JXL"))
-          error ("xlsclose: JXL doesn't support changing filename, new filename ignored.");
+          error ("xlsclose: JXL doesn't support changing filename, new filename ignored.\n");
         elseif (! ((strcmp (xls.xtype, "COM") || strcmp (xls.xtype, "UNO")) ... 
                 && isempty (strfind ( lower (filename), ".xls"))))
           # Excel/ActiveX && OOo (UNO bridge) will write any valid filetype; POI/JXL/OXS need .xls[x]
-          error ("xlsclose: .xls or .xlsx suffix lacking in filename %s", filename);
+          error ("xlsclose: .xls or .xlsx suffix lacking in filename %s\n", filename);
         else
           ## For multi-user environments, uncomment below AND relevant stanza in xlsopen
           ## In case of COM, be sure to first close the open workbook
@@ -147,7 +125,7 @@ function [ xls ] = xlsclose (xls, varargs)
   endif
 
   if (xls.changed && xls.changed < 3)
-    warning (sprintf ("xlsclose: file %s could not be saved. Read-only or in use elsewhere?", ...
+    warning (sprintf ("xlsclose: file %s could not be saved. Read-only or in use elsewhere?\n", ...
                       xls.filename));
     if (force)
       xls = [];
