@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -22,19 +22,21 @@
 ## spreadsheet file @var{filename} in cell range @var{range}. Gnumeric
 ## files can also be written.
 ##
-## @var{rstatus} returns 1 if write succeeded, 0 otherwise.
+## @var{rstatus} returns 1 if writing succeeded, 0 otherwise.
 ##
-## @var{filename} must be a valid .xls Excel file name (including file
-## name extension). If @var{filename} does not contain any directory path,
-## the file is saved in the current directory.
+## @var{filename} must be a valid Excel file name (including file
+## name extension).  If @var{filename} does not contain any directory path,
+## the file is saved in the current directory.  Writing .xlsm and .xlsb
+## is untested but may only reliably be possible with the COM and UNO
+## interfaces.
 ##
-## @var{arr} can be any 1D or 2D array containing numerical or character
-## data (cellstr) except complex. Mixed numeric/text arrays can only be
-## cell arrays.
+## @var{arr} can be any 1D or 2D array containing numerical, logical and/or
+## character data (cellstr) except complex.  Mixed numeric/text arrays can
+## only be cell arrays.
 ##
 ## If only 3 arguments are given, the 3rd is assumed to be a spreadsheet
-## range if it contains a ":" or is a completely empty string (corresponding
-## to A1:IV65336 for regular .xls or A1:XFD1048576 for OOXML .xlsx). The
+## range if it contains a ":" or is a completely empty string (interpreted
+## as A1:IV65336 for regular .xls or A1:XFD1048576 for OOXML .xlsx).  The
 ## 3rd argument is assumed to refer to a worksheet if it is a numeric value
 ## or a non-empty text string not containing ":"
 ##
@@ -51,7 +53,11 @@
 ##
 ## @var{range} is expected to be a regular spreadsheet range.
 ## Data is added to the worksheet; existing data in the requested
-## range will be overwritten.
+## range will be overwritten.  Instead of a spreadsheet range a Named
+## range defined in the spreadsheet file can be used as well. In that
+## case the Named range should be specified as 4th argument and the value
+## of 3rd argument @var{wsh} doesn't matter as the worksheet associated
+## with the specified Named range will be used.
 ## Array @var{arr} will be clipped at the right and/or bottom if its size
 ## is bigger than can be accommodated in @var{range}.
 ## If @var{arr} is smaller than the @var{range} allows, it is placed
@@ -60,21 +66,31 @@
 ##
 ## If @var{range} contains merged cells, only the elements of @var{arr}
 ## corresponding to the top or left Excel cells of those merged cells
-## will be written, other array cells corresponding to that cell will be
-## ignored.
+## will be written, other array cells corresponding to that merged cell
+## will be ignored. In other words, merged spreadsheet cells won't be
+## "unmerged".
 ##
+## As to the optional last argument @var{reqintf}: 
+## When no external support SW for spreadsheet I/O ('interface') is
+## installed (see below), xlsread can only write to .xlsx, .ods and
+## .gnumeric files using the default (built-in) 'OCT' interface.  If
+## external support SW is installed, xlswrite will try locate it
+## automatically and invoke it, allowing more file types to be written.
+## Multiple spreadsheet I/O 'interfaces' can be installed side-by-side;
+## xlswrite will then try to invoke the most suitable one depending
+## on file type.
 ## The optional last argument @var{reqintf} can be used to override 
-## the automatic selection by xlswrite of one interface out of the
-## supported ones: 'com' (ActiveX/Excel), 'poi' (Java/Apache POI), 'jxl'
-## (Java/JExcelAPI), 'uno' (Java/OpenOffice.org), or 'OCT' (native Octave
-## w/o any external support software). 'oxs' (Java/OpenXLS) has been
-## implemented but disabled for writing OOXML as it is too buggy; for
-## BIFF8 (Excel '97 .xls) it works reliably. For writing to OOXML files
-## (.xlsx) a value of 'com', 'poi', 'uno', or 'oct' must
-## be specified for @var{reqintf}. The value of @var{reqintf} is
-## case-insensitive. Multiple interfaces can be selected if entered as
-## a cell array of strings. Writing gnumeric files can only be done
-## with the OCT interface, selected automatically for those files.
+## that automatic selection by xlswrite.  Supported interfaces
+## comprise: 'com' (ActiveX/Excel), 'poi' (Java/Apache POI), 'jxl'
+## (Java/JExcelAPI), 'uno' (Java/OpenOffice.org), or 'oct' (native
+## Octave w/o any external support software).  'oxs' (Java/OpenXLS)
+## works reliably and fast for .xls (BIFF8) but has been disabled for
+## writing OOXML as that is too buggy.  For writing to OOXML files
+## (.xlsx) a value of 'com', 'poi', 'uno', or 'oct' must be specified
+## for @var{reqintf}.  The value of @var{reqintf} is case-insensitive.
+## Multiple interfaces can be selected if entered as a cell array of
+## strings.  Writing gnumeric files can only be done with the OCT
+## interface, it is selected automatically for that file type.
 ##
 ## xlswrite is a mere wrapper for various scripts which find out what
 ## Excel interface to use (COM, POI, etc) plus code to mimic the other
@@ -89,10 +105,12 @@
 ## Examples:
 ##
 ## @example
-##   status = xlswrite ('test4.xls', 'arr', 'Third_sheet', 'C3:AB40');
-##   (which adds the contents of array arr (any type) to range C3:AB40 
-##   in worksheet 'Third_sheet' in file test4.xls and returns a logical 
-##   True (= numerical 1) in status if al went well) 
+##   status = xlswrite ...
+##            ('test4.xls', 'arr', 'Third_sheet', 'C3:AB40');
+##   (which adds the contents of array arr (any type) to
+##    rangeC3:AB40 in worksheet 'Third_sheet' in file
+##    test4.xls and returns a logical True (= numerical 1)
+##    in 'status' if all went well) 
 ## @end example
 ##
 ## @seealso {xlsread, oct2xls, xls2oct, xlsopen, xlsclose, xlsfinfo}
@@ -101,26 +119,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis at users.sf.net>
 ## Created: 2009-10-16
-## Updates:
-## 2010-01-04 (Adapted range capacity checks to OOXML)
-## 2010-01-12 (Bug fix; added unwind_protect to xlsopen...xlsclose calls)
-## 2010-01-15 Fixed typos in texinfo
-## 2010-08-18 Added check for existence of xls after call to xlsopen to 
-##            avoid unneeded error message clutter
-## 2010-10-27 Changed range -> crange to unhide other range functions
-## 2011-09-08 Minor code syntax updates
-## 2012-01-26 Fixed "seealso" help string
-## 2012-06-07 Replaced all tabs by double space
-## 2012-10-24 Style fixes
-## 2012-12-23 Fix rare occasion of xlsclose error in unwind_protect block
-## 2012-04-17 Fix checks on xls or xls? suffix (due to Vermylen)
-## 2012-04-21 Improve xls/xlsx suffix check
-## 2013-12-07 Updated copyright string
-##     ''     Check on empty file ptr struct after calling xlsopen
-## 2014-03-18 Convey full crange to oct2xls, not just topleft
-## 2014-04-13 Update texinfo header
-## 2014-04-26 Fixed error message (no traceback)
-## 2014-08-14 Return 0 in case non-empty file pointer after closing
 
 function [ rstatus ] = xlswrite (filename, arr, arg3, arg4, arg5)
 
@@ -128,7 +126,7 @@ function [ rstatus ] = xlswrite (filename, arr, arg3, arg4, arg5)
 
   ## Sanity checks
   if (nargin < 2)
-    usage ("Insufficient arguments - see 'help xlswrite'");
+    error ("Insufficient arguments - see 'help xlswrite'\n");
   elseif (! ischar (filename))
     error ("xlswrite: first argument must be a filename (incl. suffix)\n");
   elseif (nargin == 2)
@@ -163,6 +161,16 @@ function [ rstatus ] = xlswrite (filename, arr, arg3, arg4, arg5)
   else
     reqintf = [];
   endif
+  if (isempty (wsh))
+    wsh = 1;
+  endif
+  if (isempty (crange))
+    if (strcmpi (filename(end-4:end-1), ".xls"))
+      crange = "A1:XFD1048576"; ## OOXML has ridiculously large limits 
+    else
+      crange = "A1:IV65536";    ## Regular xls limits
+    endif
+  endif
   
   ## Parse range
   [topleft, nrows, ncols, trow, lcol] = parse_sp_range (crange);
